@@ -1,4 +1,4 @@
-import json
+import ast
 from functools import wraps
 from sqlalchemy.orm.base import object_mapper
 import flask_sqlalchemy
@@ -39,6 +39,14 @@ def serializer(schema=None, many=False):
                     client_data = request.json
                 elif request.form:
                     client_data = request.form.to_dict()
+                    for _k in client_data.keys():
+                        try:
+                            value = ast.literal_eval(client_data[_k])
+                            if isinstance(value, int):
+                                value = str(value)
+                            client_data[_k] = value
+                        except Exception:
+                            pass
 
                 if request.args:
                     client_data.update(request.args.to_dict())
