@@ -2,7 +2,7 @@ from wedeliver_core import WeDeliverCore
 
 
 def get_prefix(service_url):
-    app = WeDeliverCore.getApp()
+    app = WeDeliverCore.get_app()
     final_url = ""
     service_name = app.config.get("SERVICE_NAME")
     if service_name:
